@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2021 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -182,6 +182,21 @@ signals:
      * Use it to show player's window and to raise it to the top.
      */
     void showMainWindowCalled();
+    /*!
+     * Emitted when some general plugin adds widget.
+     * User interface should create this widget using the given \b id.
+     */
+    void widgetAdded(const QString &id);
+    /*!
+     * Emitted when some general plugin removes widget \b id.
+     * User interface should remove widget with the given \b id.
+     */
+    void widgetRemoved(const QString &id);
+    /*!
+     * Emitted when some general plugin changes settings of the widget \b id.
+     * User interface should recreate widget with the given \b id.
+     */
+    void widgetUpdated(const QString &id);
 
 private slots:
     void removeAction(QObject *action);
